<?php

namespace App\Controller\Admin;

use App\Controller\Admin\AppController;
use Cake\Controller\Component\CustomComponent;
use Cake\ORM\TableRegistry;
use Cake\ORM\find;
use Cake\View\CellTrait;

/**
 * Activities Controller
 *
 * @property \App\Model\Table\ActivitiesTable $Activities
 */
class ActivitiesController extends AppController {

    public function initialize() {
        parent::initialize();
        $this->loadComponent('Custom');
        $this->Auth->allow('ls_article');
    }

    /**
     * Index method
     *
     * @return void
     */
    public function index() {
        $this->paginate = [
            'contain' => [],
        ];
        $this->set('activities', $this->paginate($this->Activities));
        $this->set('_serialize', ['activities']);
    }

    /**
     * View method
     *
     * @param string|null $id Category id.
     * @return void
     * @throws \Cake\Network\Exception\NotFoundException When record not found.
     */
    public function view($id = null) {
        $article = $this->Activities->get($id, [
            'contain' => []
        ]);
        $this->set('article', $article);
        $this->set('_serialize', ['article']);
    }

    /**
     * Add method
     *
     * @return void Redirects on successful add, renders view otherwise.
     */
    public function add() {
        $article = $this->Activities->newEntity();
        if ($this->request->is('post')) {
            //pr($this->request->data);die;
            $article = $this->Activities->patchEntity($article, $this->request->data);
            if ($status = $this->Activities->save($article)) {
                if (!isset($this->request->data['image']['error']) ? $this->request->data['image']['error'] : TRUE) {
                    $file = $this->Activities->saveFile($status, $this->request->data['image']);
                }
                $this->Flash->success('The article has been saved.');
                return $this->redirect(['action' => 'index']);
            } else {
                $this->Flash->error('The article could not be saved. Please, try again.');
            }
        }
        $this->set('isEdit', FALSE);
        $this->set(compact('article'));
        $this->set('_serialize', ['article']);
    }

    /**
     * Edit method
     *
     * @param string|null $id Category id.
     * @return void Redirects on successful edit, renders view otherwise.
     * @throws \Cake\Network\Exception\NotFoundException When record not found.
     */
    public function edit($id = null) {
        $article = $this->Activities->get($id, [
            'contain' => []
        ]);
        if ($this->request->is(['patch', 'post', 'put'])) {
            $img = 1;
            if ($this->request->data['image']['name'] == "") {
                unset($this->request->data['image']);
                $img = 0;
            }
            $article = $this->Activities->patchEntity($article, $this->request->data);
            if ($status = $this->Activities->save($article)) {
                if ($img == 1) {
                    $file = $this->Activities->saveFile($status, $this->request->data['image']);
                }
                $this->Flash->success('The article has been saved.');
                return $this->redirect(['action' => 'index']);
            } else {
                $this->Flash->error('The article could not be saved. Please, try again.');
            }
        }
        $this->set('isEdit', TRUE);
        $this->set(compact('article'));
        $this->set('_serialize', ['article']);
    }

    public function status($id = null, $status = 0) {
        $article = $this->Activities->get($id, [
            'contain' => []
        ]);
        if (!empty($article)) {
            $this->request->data['status'] = $status;
            $article = $this->Activities->patchEntity($article, $this->request->data);
            if ($this->Activities->save($article)) {
                $this->Flash->success('The article has been saved.');
                return $this->redirect(['action' => 'index']);
            } else {
                $this->Flash->error('The article could not be saved. Please, try again.');
            }
        } else {
            $this->Flash->error('The article could not be saved. Please, try again.');
        }
    }

    /**
     * Delete method
     *
     * @param string|null $id Category id.
     * @return void Redirects to index.
     * @throws \Cake\Network\Exception\NotFoundException When record not found.
     */
    public function delete($id = null) {
        $this->request->allowMethod(['post', 'delete']);
        $article = $this->Activities->get($id);
        if ($this->Activities->delete($article)) {
            $this->Flash->success('The article has been deleted.');
        } else {
            $this->Flash->error('The article could not be deleted. Please, try again.');
        }
        return $this->redirect(['action' => 'index']);
    }

}
