<?php

namespace App\Controller\Admin;

use App\Controller\Admin\AppController;
use Cake\Controller\Component\CustomComponent;
use Cake\ORM\TableRegistry;
use Cake\ORM\find;
use Cake\View\CellTrait;

/**
 * Categories Controller
 *
 * @property \App\Model\Table\CategoriesTable $Categories
 */
class CategoriesController extends AppController {

    public function initialize() {
        parent::initialize();
        $this->loadComponent('Custom');
        $this->Auth->allow('ls_category');
    }

    /**
     * Index method
     *
     * @return void
     */
    public function index() {
        $this->paginate = [
            'contain' => ['SubCategories'],
            'conditions' => ['Categories.category_id' => 0]
        ];
        $this->set('categories', $this->paginate($this->Categories));
        $this->set('_serialize', ['categories']);
    }

    /**
     * View method
     *
     * @param string|null $id Category id.
     * @return void
     * @throws \Cake\Network\Exception\NotFoundException When record not found.
     */
    public function view($id = null) {
        $category = $this->Categories->get($id, [
            'contain' => []
        ]);
        $this->set('category', $category);
        $this->set('_serialize', ['category']);
    }

    /**
     * Add method
     *
     * @return void Redirects on successful add, renders view otherwise.
     */
    public function add() {
        $category = $this->Categories->newEntity();
        if ($this->request->is('post')) {
            //pr($this->request->data);die;
            $category = $this->Categories->patchEntity($category, $this->request->data);
            if ($status = $this->Categories->save($category)) {
                if (!isset($this->request->data['image']['error']) ? $this->request->data['image']['error'] : TRUE) {
                    $file = $this->Categories->saveFile($status, $this->request->data['image']);
                }
                $this->Flash->success('The category has been saved.');
                return $this->redirect(['action' => 'index']);
            } else {
                $this->Flash->error('The category could not be saved. Please, try again.');
            }
        }
        $categories_data = $this->Categories->find('list', ['fields' => ['id', 'name']])
                ->where(['category_id' => 0, 'status' => 1])
                ->all()
                ->toArray();
        $this->set('categories_data', $categories_data);
        $this->set('isEdit', FALSE);
        $this->set(compact('category'));
        $this->set('_serialize', ['category']);
    }

    /**
     * Edit method
     *
     * @param string|null $id Category id.
     * @return void Redirects on successful edit, renders view otherwise.
     * @throws \Cake\Network\Exception\NotFoundException When record not found.
     */
    public function edit($id = null) {
        $category = $this->Categories->get($id, [
            'contain' => []
        ]);
        if ($this->request->is(['patch', 'post', 'put'])) {
            $img = 1;
            if ($this->request->data['image']['name'] == "") {
                unset($this->request->data['image']);
                $img = 0;
            }
            $category = $this->Categories->patchEntity($category, $this->request->data);
            if ($status = $this->Categories->save($category)) {
                if ($img == 1) {
                    $file = $this->Categories->saveFile($status, $this->request->data['image']);
                }
                $this->Flash->success('The category has been saved.');
                return $this->redirect(['action' => 'index']);
            } else {
                $this->Flash->error('The category could not be saved. Please, try again.');
            }
        }
        $categories_data = $this->Categories->find('list', ['fields' => ['id', 'name']])
                ->where(['category_id' => 0, 'status' => 1])
                ->all()
                ->toArray();

        $this->set('isEdit', TRUE);
        $this->set(compact('category', 'categories_data'));
        $this->set('_serialize', ['category', 'categories_data']);
    }

    public function status($id = null, $status = 0) {
        $category = $this->Categories->get($id, [
            'contain' => []
        ]);
        if (!empty($category)) {
            $this->request->data['status'] = $status;
            $category = $this->Categories->patchEntity($category, $this->request->data);
            if ($this->Categories->save($category)) {
                $this->Flash->success('The category has been saved.');
                return $this->redirect(['action' => 'index']);
            } else {
                $this->Flash->error('The category could not be saved. Please, try again.');
            }
        } else {
            $this->Flash->error('The category could not be saved. Please, try again.');
        }
    }

    /**
     * Delete method
     *
     * @param string|null $id Category id.
     * @return void Redirects to index.
     * @throws \Cake\Network\Exception\NotFoundException When record not found.
     */
    public function delete($id = null) {
        $this->request->allowMethod(['post', 'delete']);
        $category = $this->Categories->get($id);
        if ($this->Categories->delete($category)) {
            $this->Flash->success('The category has been deleted.');
        } else {
            $this->Flash->error('The category could not be deleted. Please, try again.');
        }
        return $this->redirect(['action' => 'index']);
    }

    public function getSubCategories() {
        $category_id = $this->request->query['category_id'];

        $subCategories = $this->Categories->find('list', [
                    'conditions' => [
                        'Categories.category_id' => $category_id,
                        'Categories.subcategory_id' => 0
                    ],
                ])->where(['status' => 1])->toArray();

        if (empty($subCategories)) {
            $response = [
                'states' => 'error',
                'message' => __('Seems to be Wrong Category Id'),
                'data' => array(),
            ];
        } else {
            $response = [
                'status' => 'success',
                'data' => $subCategories,
            ];
        }

        $this->set('response', $response);

        $this->viewBuilder()->layout = 'ajax';
        $this->render('/Element/Ajax/get');
    }

    public function getSecSubCategories() {
        $category_id = $this->request->query['subcategory_id'];

        $subCategories = $this->Categories->find('list', [
                    'conditions' => [
                        'Categories.subcategory_id' => $category_id
                    ],
                ])->where(['status' => 1])->toArray();

        if (empty($subCategories)) {
            $response = [
                'states' => 'error',
                'message' => __('Seems to be Wrong Category Id'),
                'data' => array(),
            ];
        } else {
            $response = [
                'status' => 'success',
                'data' => $subCategories,
            ];
        }

        $this->set('response', $response);

        $this->viewBuilder()->layout = 'ajax';
        $this->render('/Element/Ajax/get');
    }

}
