<?php

namespace App\Controller\Admin;

use App\Controller\Admin\AppController;
use Cake\Event\Event;

/**
 * Gallerycategories Controller
 *
 * @property \App\Model\Table\GallerycategoriesTable $Gallerycategories
 */
class GallerycategoriesController extends AppController {

    /**
     * Index method
     *
     * @return void
     */
    public function index() {
        $this->paginate = [
            'limit' => 25000000
        ];
        $this->set('gallerycategories', $this->paginate($this->Gallerycategories));
        $this->set('_serialize', ['gallerycategories']);
    }

    /**
     * View method
     *
     * @param string|null $id Country id.
     * @return void
     * @throws \Cake\Network\Exception\NotFoundException When record not found.
     */
    public function view($id = null) {
        $gallerycategories = $this->Gallerycategories->get($id, [
            'contain' => ['Branches', 'Cities', 'States']
        ]);
        $this->set('gallerycategories', $gallerycategories);
        $this->set('_serialize', ['gallerycategories']);
    }

    /**
     * Add method
     *
     * @return void Redirects on successful add, renders view otherwise.
     */
    public function add() {
        $gallerycategories = $this->Gallerycategories->newEntity();
        if ($this->request->is('post')) {
            $gallerycategories = $this->Gallerycategories->patchEntity($gallerycategories, $this->request->data);
            if ($this->Gallerycategories->save($gallerycategories)) {
                $this->Flash->success('The gallerycategories has been saved.');
                return $this->redirect(['action' => 'index']);
            } else {
                $this->Flash->error('The gallerycategories could not be saved. Please, try again.');
            }
        }

        $this->set(compact('gallerycategories'));
        $this->set('_serialize', ['gallerycategories']);
        $this->set('isEdit', FALSE);
    }

    /**
     * Edit method
     *
     * @param string|null $id Country id.
     * @return void Redirects on successful edit, renders view otherwise.
     * @throws \Cake\Network\Exception\NotFoundException When record not found.
     */
    public function edit($id = null) {
        $gallerycategories = $this->Gallerycategories->get($id, [
            'contain' => []
        ]);

        if ($this->request->is(['patch', 'post', 'put'])) {
            $gallerycategories = $this->Gallerycategories->patchEntity($gallerycategories, $this->request->data);
            if ($this->Gallerycategories->save($gallerycategories)) {
                $this->Flash->success('The gallerycategories has been saved.');
                return $this->redirect(['action' => 'index']);
            } else {
                $this->Flash->error('The gallerycategories could not be saved. Please, try again.');
            }
        }

        $this->gallerycategoriesData = $gallerycategories;

        $this->set(compact('gallerycategories'));
        $this->set('_serialize', ['gallerycategories']);
        $this->set('isEdit', TRUE);

        $this->render('add');
    }

    /**
     * Delete method
     *
     * @param string|null $id Country id.
     * @return void Redirects to index.
     * @throws \Cake\Network\Exception\NotFoundException When record not found.
     */
    public function delete($id = null) {
        $this->request->allowMethod(['post', 'delete']);
        $gallerycategories = $this->Gallerycategories->get($id);
        if ($this->Gallerycategories->delete($gallerycategories)) {
            $this->Flash->success('The gallerycategories has been deleted.');
        } else {
            $this->Flash->error('The gallerycategories could not be deleted. Please, try again.');
        }
        return $this->redirect(['action' => 'index']);
    }

    public function status($id = null, $status = 0) {
        $category = $this->Gallerycategories->get($id, [
            'contain' => []
        ]);
        if (!empty($category)) {
            $this->request->data['status'] = $status;
            $category = $this->Gallerycategories->patchEntity($category, $this->request->data);
            if ($this->Gallerycategories->save($category)) {
                $this->Flash->success('The Country has been saved.');
                return $this->redirect(['action' => 'index']);
            } else {
                $this->Flash->error('The Country could not be saved. Please, try again.');
            }
        } else {
            $this->Flash->error('The Country could not be saved. Please, try again.');
        }
    }

    /**
     * 
     * Overrides the Default beforeRednder Method To add Breadcrumbs and other
     * Stuff
     * 
     * @param Event $event
     * @return void 
     */
    public function beforeRender(Event $event) {

        $this->breadcrumbs[] = [
            'label' => __('Gallerycategories'),
            'link' => [
                'controller' => 'gallerycategories',
                'action' => 'index',
            ],
        ];

        switch ($this->request->params['action']) {
            default:
            case 'index':
                break;
            case 'add':
                $this->breadcrumbs[] = [
                    'label' => __('Add'),
                    'link' => NULL,
                ];
                break;
            case 'edit':
                $this->breadcrumbs[] = [
                    'label' => __('Edit'),
                ];

                $this->breadcrumbs[] = [
                    'label' => $this->gallerycategoriesData->name,
                ];

                break;
        }
        parent::beforeRender($event);
    }

}
