<?php

namespace App\Controller\Admin;

use App\Controller\Admin\AppController;
use Cake\Event\Event;

/**
 * Gallerypost Controller
 *
 * @property \App\Model\Table\GallerypostTable $Gallerypost
 */
class GallerypostController extends AppController {

    public function beforeFilter(Event $event) {

        parent::beforeFilter($event);
        $this->Auth->allow(['getGallerypost']);
    }

    /**
     * Index method
     *
     * @return void
     */
    public function index() {
        $this->paginate = [
            'contain' => ['Gallerycategories'],
            'limit' => 255555555
        ];
        $this->set('gallerypost', $this->paginate($this->Gallerypost));
        $this->set('_serialize', ['gallerypost']);
    }

    /**
     * View method
     *
     * @param string|null $id Gallerypost id.
     * @return void
     * @throws \Cake\Network\Exception\NotFoundException When record not found.
     */
    public function view($id = null) {
        $gallerypost = $this->Gallerypost->get($id, [
            'contain' => ['Gallerycategories', 'Branches', 'Cities']
        ]);
        $this->set('gallerypost', $gallerypost);
        $this->set('_serialize', ['gallerypost']);
    }

    /**
     * Add method
     *
     * @return void Redirects on successful add, renders view otherwise.
     */
    public function add() {
        $gallerypost = $this->Gallerypost->newEntity();
        if ($this->request->is('post')) {
            $gallerypost = $this->Gallerypost->patchEntity($gallerypost, $this->request->data);
			
			if ($status = $this->Gallerypost->save($gallerypost)) {
                if (!isset($this->request->data['image']['error']) ? $this->request->data['image']['error'] : TRUE) {
                    $file = $this->Gallerypost->saveFile($status, $this->request->data['image']);
                }
                $this->Flash->success('The gallerypost has been saved.');
                return $this->redirect(['action' => 'index']);
            } else {
                $this->Flash->error('The gallerypost could not be saved. Please, try again.');
            }
			
			
            //if ($this->Gallerypost->save($gallerypost)) {
//                $this->Flash->success('The gallerypost has been saved.');
//                return $this->redirect(['action' => 'index']);
//            } else {
//                $this->Flash->error('The gallerypost could not be saved. Please, try again.');
//            }
        }
        $gallerycategories = $this->Gallerypost->Gallerycategories->find('list', ['limit' => 200])->where(['status' => 1]);

        $this->set(compact('gallerypost', 'gallerycategories'));
        $this->set('_serialize', ['gallerypost']);
        $this->set('isEdit', FALSE);
    }

    /**
     * Edit method
     *
     * @param string|null $id Gallerypost id.
     * @return void Redirects on successful edit, renders view otherwise.
     * @throws \Cake\Network\Exception\NotFoundException When record not found.
     */
    public function edit($id = null) {
        $gallerypost = $this->Gallerypost->get($id, [
            'contain' => []
        ]);
        if ($this->request->is(['patch', 'post', 'put'])) {
            $gallerypost = $this->Gallerypost->patchEntity($gallerypost, $this->request->data);
            if ($status = $this->Gallerypost->save($gallerypost)) {
                if (!isset($this->request->data['image']['error']) ? $this->request->data['image']['error'] : TRUE) {
                    $file = $this->Gallerypost->saveFile($status, $this->request->data['image']);
                }
                $this->Flash->success('The gallerypost has been saved.');
                return $this->redirect(['action' => 'index']);
            } else {
                $this->Flash->error('The gallerypost could not be saved. Please, try again.');
            }
        }

        $gallerycategories = $this->Gallerypost->Gallerycategories->find('list', ['limit' => 200])->where(['status' => 1]);

        $this->set(compact('gallerypost', 'gallerycategories'));
        $this->set('_serialize', ['gallerypost']);
        $this->set('isEdit', TRUE);

        $this->dataGallerypost = $gallerypost;
        $this->render('add');
    }

    /**
     * Delete method
     *
     * @param string|null $id Gallerypost id.
     * @return void Redirects to index.
     * @throws \Cake\Network\Exception\NotFoundException When record not found.
     */
    public function delete($id = null) {
        $this->request->allowMethod(['post', 'delete']);
        $gallerypost = $this->Gallerypost->get($id);
        if ($this->Gallerypost->delete($gallerypost)) {
            $this->Flash->success('The gallerypost has been deleted.');
        } else {
            $this->Flash->error('The gallerypost could not be deleted. Please, try again.');
        }
        return $this->redirect(['action' => 'index']);
    }

    public function getGallerypost() {
        $country_id = $this->request->query['country_id'];

        $galleryposts = $this->Gallerypost->find('list', [
                    'conditions' => [
                        'Gallerypost.country_id' => $country_id
                    ],
                ])->where(['status' => 1])->toArray();

        if (empty($galleryposts)) {
            $response = [
                'galleryposts' => 'error',
                'message' => __('Seems to be Wrong Country Id'),
                'data' => array(),
            ];
        } else {
            $response = [
                'status' => 'success',
                'data' => $galleryposts,
            ];
        }

        $this->set('response', $response);

        $this->viewBuilder()->layout('ajax');
        $this->render('/Element/Ajax/get');
    }

    public function status($id = null, $status = 0) {
        $category = $this->Gallerypost->get($id, [
            'contain' => []
        ]);
        if (!empty($category)) {
            $this->request->data['status'] = $status;
            $category = $this->Gallerypost->patchEntity($category, $this->request->data);
            if ($this->Gallerypost->save($category)) {
                $this->Flash->success('The Gallerypost has been saved.');
                return $this->redirect(['action' => 'index']);
            } else {
                $this->Flash->error('The Gallerypost could not be saved. Please, try again.');
            }
        } else {
            $this->Flash->error('The Gallerypost could not be saved. Please, try again.');
        }
    }

    public function beforeRender(Event $event) {

        $this->breadcrumbs[] = [
            'label' => __('Gallerypost'),
            'link' => [
                'action' => 'index',
            ]
        ];

        switch ($this->request->params['action']) {
            case 'view':

                $this->breadcrumbs[] = [
                    'label' => __('Add')
                ];

                break;
            case 'add':
                $this->breadcrumbs[] = [
                    'label' => __('Add')
                ];
                break;
            case 'edit':
                $this->breadcrumbs[] = [
                    'label' => __('Edit')
                ];

                $this->breadcrumbs[] = [
                    'label' => $this->dataGallerypost->name,
                ];
                break;
        }

        parent::beforeRender($event);
    }

}
