<?php

namespace App\Controller\Admin;

use App\Controller\Admin\AppController;
use Cake\Event\Event;
use Cake\ORM\TableRegistry;

/**
 * Locations Controller
 *
 * @property \App\Model\Table\LocationsTable $Locations
 */
class LocationsController extends AppController {

    /**
     * Index method
     *
     * @return void
     */
    public function index() {
        $this->paginate = [
            'contain' => ['Cities', 'States', 'Countries'],
            'limit' => 25000000
        ];
        $stateId = $this->request->query('state_id');
        if (!empty($stateId)) {
            $this->States = TableRegistry::get('States');
            $state = $this->States->get($stateId, [
                'contain' => []
            ]);
            if (!empty($state))
                $this->paginate['conditions'] = ['Locations.state_id' => $stateId];
        }

        $this->set('locations', $this->paginate($this->Locations));
        $this->set('_serialize', ['locations']);
    }

    /**
     * View method
     *
     * @param string|null $id Location id.
     * @return void
     * @throws \Cake\Network\Exception\NotFoundException When record not found.
     */
    public function view($id = null) {
        $location = $this->Locations->get($id, [
            'contain' => ['Cities', 'States', 'Countries']
        ]);
        $this->set('location', $location);
        $this->set('_serialize', ['location']);
    }

    /**
     * Add method
     *
     * @return void Redirects on successful add, renders view otherwise.
     */
    public function add() {
        $location = $this->Locations->newEntity();
        if ($this->request->is('post')) {
            $location = $this->Locations->patchEntity($location, $this->request->data);
            if ($this->Locations->save($location)) {
                $this->Flash->success('The location has been saved.');
                return $this->redirect(['action' => 'index']);
            } else {
                $this->Flash->error('The location could not be saved. Please, try again.');
            }
        }
        $cities = $this->Locations->Cities->find('list', ['limit' => 200])->where(['status' => 1]);
        $states = $this->Locations->States->find('list', ['limit' => 200])->where(['status' => 1]);
        $countries = $this->Locations->Countries->find('list', ['limit' => 200])->where(['status' => 1]);

        $this->set(compact('location', 'states', 'countries', 'cities'));
        $this->set('_serialize', ['location']);
        $this->set('isEdit', FALSE);
    }

    /**
     * Edit method
     *
     * @param string|null $id Location id.
     * @return void Redirects on successful edit, renders view otherwise.
     * @throws \Cake\Network\Exception\NotFoundException When record not found.
     */
    public function edit($id = null) {
        $location = $this->Locations->get($id, [
            'contain' => []
        ]);
        if ($this->request->is(['patch', 'post', 'put'])) {
            $location = $this->Locations->patchEntity($location, $this->request->data);
            if ($this->Locations->save($location)) {
                $this->Flash->success('The location has been saved.');
                return $this->redirect(['action' => 'index']);
            } else {
                $this->Flash->error('The location could not be saved. Please, try again.');
            }
        }
        $cities = $this->Locations->Cities->find('list', ['limit' => 200])->where(['status' => 1]);
        $states = $this->Locations->States->find('list', ['limit' => 200])->where(['status' => 1]);
        $countries = $this->Locations->Countries->find('list', ['limit' => 200])->where(['status' => 1]);
        $this->set(compact('location', 'states', 'countries', 'cities'));
        $this->set('_serialize', ['location']);
        $this->set('isEdit', TRUE);

        $this->locationData = $location;

        $this->render('add');
    }

    public function status($id = null, $status = 0) {
        $category = $this->Locations->get($id, [
            'contain' => []
        ]);
        if (!empty($category)) {
            $this->request->data['status'] = $status;
            $category = $this->Locations->patchEntity($category, $this->request->data);
            if ($this->Locations->save($category)) {
                $this->Flash->success('The Location has been saved.');
                return $this->redirect(['action' => 'index']);
            } else {
                $this->Flash->error('The Location could not be saved. Please, try again.');
            }
        } else {
            $this->Flash->error('The Location could not be saved. Please, try again.');
        }
    }

    /**
     * Delete method
     *
     * @param string|null $id Location id.
     * @return void Redirects to index.
     * @throws \Cake\Network\Exception\NotFoundException When record not found.
     */
    public function delete($id = null) {
        $this->request->allowMethod(['post', 'delete']);
        $location = $this->Locations->get($id);
        if ($this->Locations->delete($location)) {
            $this->Flash->success('The location has been deleted.');
        } else {
            $this->Flash->error('The location could not be deleted. Please, try again.');
        }
        return $this->redirect(['action' => 'index']);
    }

    function getLocations() {

        $city_id = $this->request->query['city_id'];
        $cities = $this->Locations->find('list', [
                    'conditions' => [
                        'Locations.city_id' => $city_id
                    ],
                ])->where(['status' => 1])->toArray();

        if (empty($cities)) {
            $response = [
                'states' => 'error',
                'message' => __('Seems to be Wrong Country Id'),
                'data' => array(),
            ];
        } else {
            $response = [
                'status' => 'success',
                'data' => $cities
            ];
        }

        $this->set('response', $response);
        $this->layout = 'ajax';
        $this->render('/Element/Ajax/get');
    }

    public function beforeRender(Event $event) {

        $this->breadcrumbs[] = [
            'label' => __('Location'),
            'link' => [
                'action' => 'index',
            ],
        ];

        switch ($this->request->params['action']) {
            case 'view':

                $this->breadcrumbs[] = [
                    'label' => __('View'),
                ];

                break;
            case 'add':

                $this->breadcrumbs[] = [
                    'label' => __('Add'),
                    'link' => NULL,
                ];

                break;
            case 'edit':

                $this->breadcrumbs[] = [
                    'label' => __('Edit'),
                ];

                $this->breadcrumbs[] = [
                    'label' => $this->locationData->name,
                ];

                break;
        }

        parent::beforeRender($event);
    }

}
