<?php

/**
 * CakePHP(tm) : Rapid Development Framework (http://cakephp.org)
 * Copyright (c) Cake Software Foundation, Inc. (http://cakefoundation.org)
 *
 * Licensed under The MIT License
 * For full copyright and license information, please see the LICENSE.txt
 * Redistributions of files must retain the above copyright notice.
 *
 * @copyright Copyright (c) Cake Software Foundation, Inc. (http://cakefoundation.org)
 * @link      http://cakephp.org CakePHP(tm) Project
 * @since     0.2.9
 * @license   http://www.opensource.org/licenses/mit-license.php MIT License
 */

namespace App\Controller\Admin;

use App\Controller\Admin\AppController;
use Cake\Core\Configure;
use Cake\Network\Exception\NotFoundException;
use Cake\View\Exception\MissingTemplateException;
use Cake\ORM\TableRegistry;
use Cake\Event\Event;

/**
 * Static content controller
 *
 * This controller will render views from Template/Pages/
 *
 * @link http://book.cakephp.org/3.0/en/controllers/pages-controller.html
 */
class PagesController extends AppController {

    /**
     * Displays a view
     *
     * @return void|\Cake\Network\Response
     * @throws \Cake\Network\Exception\NotFoundException When the view file could not
     *   be found or \Cake\View\Exception\MissingTemplateException in debug mode.
     */
    public function display() {
        $path = func_get_args();

        $count = count($path);
        if (!$count) {
            return $this->redirect('/');
        }
        $page = $subpage = null;

        if (!empty($path[0])) {
            $page = $path[0];
        }
        if (!empty($path[1])) {
            $subpage = $path[1];
        }
        $this->set(compact('page', 'subpage'));

        try {
            /**
             * 
             * @todo we can have the custom Sql Query here fired over the database
             * which will give all the required result in the single Query should 
             * be considered for the optimization phase.
             */
            $users = TableRegistry::get('Users');
            $totalusers = $users->find('all')->where(['Users.admin' => 0]);

            $this->set('total', [
                'products' => 0,
                'users' => $totalusers,
                'categories' => 0,
                'activities' => 0,
            ]);

            $this->render(implode('/', $path));
        } catch (MissingTemplateException $e) {
            if (Configure::read('debug')) {
                throw $e;
            }
            throw new NotFoundException();
        }
    }

    /**
     * Index method
     *
     * @return void
     */
    public function index() {
        $this->paginate = [
            'limit' => 25000000
        ];
        $this->set('pages', $this->paginate($this->Pages));
        $this->set('_serialize', ['pages']);
    }

    public function add() {
        $pages = $this->Pages->newEntity();
        if ($this->request->is('post')) {
            $pages = $this->Pages->patchEntity($pages, $this->request->data);
            if ($this->Pages->save($pages)) {
                $this->Flash->success('The Pages has been saved.');
                return $this->redirect(['action' => 'index']);
            } else {
                $this->Flash->error('The pages could not be saved. Please, try again.');
            }
        }

        $this->set(compact('pages'));
        $this->set('_serialize', ['pages']);
        $this->set('isEdit', FALSE);
    }

    public function edit($id = null) {
        $pages = $this->Pages->get($id, [
            'contain' => []
        ]);

        if ($this->request->is(['patch', 'post', 'put'])) {
            $pages = $this->Pages->patchEntity($pages, $this->request->data);
            if ($this->Pages->save($pages)) {
                $this->Flash->success('The Pages has been saved.');
                return $this->redirect(['action' => 'index']);
            } else {
                $this->Flash->error('The Pages could not be saved. Please, try again.');
            }
        }

        $this->countryData = $pages;

        $this->set(compact('pages'));
        $this->set('_serialize', ['pages']);
        $this->set('isEdit', TRUE);

        $this->render('add');
    }

    public function delete($id = null) {
        $this->request->allowMethod(['post', 'delete']);
        $pages = $this->Pages->get($id);
        if ($this->Pages->delete($pages)) {
            $this->Flash->success('The Pages has been deleted.');
        } else {
            $this->Flash->error('The Pages could not be deleted. Please, try again.');
        }
        return $this->redirect(['action' => 'index']);
    }

    /**
     * 
     * Overrides the Default beforeRednder Method To add Breadcrumbs and other
     * Stuff
     * 
     * @param Event $event
     * @return void 
     */
    public function beforeRender(Event $event) {

        $this->breadcrumbs[] = [
            'label' => __('Pages'),
            'link' => [
                'controller' => 'pages',
                'action' => 'index',
            ],
        ];

        switch ($this->request->params['action']) {
            default:
            case 'index':
                break;
            case 'add':
                $this->breadcrumbs[] = [
                    'label' => __('Add'),
                    'link' => NULL,
                ];
                break;
            case 'edit':
                $this->breadcrumbs[] = [
                    'label' => __('Edit'),
                ];

                $this->breadcrumbs[] = [
                    'label' => $this->countryData->name,
                ];

                break;
        }
        parent::beforeRender($event);
    }

}
