<?php

namespace App\Controller\Admin;

use App\Controller\Admin\AppController;
use Cake\Event\Event;
use Cake\ORM\TableRegistry;
use Cake\Network\Email\Email;
use App\Network\Email\MandrillTransport;
use Cake\Datasource\ConnectionManager;
use Cake\Core\Configure;

/**
 * 
 * Users Controller
 *
 * @property \App\Model\Table\UsersTable $Users
 * @property \App\Model\Table\DevelopmentOfficersTable $DevelopmentOfficers
 * @property \App\Model\Table\AgentsTable $Agents 
 * @property \App\Model\Table\BranchesTable $Branches 
 */
class UsersController extends AppController {

    public function beforeFilter(Event $event) {

        parent::beforeFilter($event);
        $this->loadModel('UserFields');
        $this->loadModel('UserTypes');
        $this->Auth->allow('login', 'unauthorize');
        $this->conn = ConnectionManager::get('default');
    }

    /**
     * Index method
     *
     * @return void
     */
    public function index() {
        $session = $this->request->session();
        $userID = $session->read('Auth.User.id');
        $userType = $session->read('userType');

        if ($userType == 'customer') {
            $this->paginate = [
                'conditions' => ['Users.id' => $userID]
            ];
        } else {
            $this->paginate = [
                'conditions' => ['Users.id !=' => 1]
            ];
        }
        $this->set('users', $this->paginate($this->Users));
        $this->set('_serialize', ['users']);
    }

    /**
     * View method
     *
     * @param string|null $id User id.
     * @return void
     * @throws \Cake\Network\Exception\NotFoundException When record not found.
     */
    public function view($id = null) {
        if (is_null($id))
            $id = $this->current_user['id'];

        $user = $this->Users->get($id, [
            'contain' => []
        ]);
        $userlog = $this->Userlogs->find('all', [
                    'contain' => []
                ])->where(['user_id' => $id])->first();
        if (!$userlog) {
            $userlog = $this->Users->get($id, [
                'contain' => []
            ]);
        }
        $user_id = $id;
        $user_fields = $this->UserFields->find('all');
        $user_types = $this->UserTypes->find('list', [
                    'keyField' => 'field_name',
                    'valueField' => 'field_title',
                ])->toArray();
        foreach ($user_types as $key => $value):
            $userlog->accessible($key, true);
        endforeach;
        foreach ($user_fields as $user_field):
            $userlog->accessible($user_field->field_name, true);
        endforeach;
        if ($this->request->is(['patch', 'post', 'put'])) {
            if ($this->request->data['sub_status'] == 1) {
                //pr($this->request->data); die;
                $userlog = $this->Userlogs->find('all')->where(['user_id' => $user_id])->first()->toArray();
                $user = $this->Users->find('all')->where(['id' => $user_id])->first();
                $userlog = $this->Userlogs->patchEntity($user, $userlog);
                if ($result = $this->Users->save($userlog)) {
                    $insert_id = $result->id;
                    $this->Flash->success('The user has been updated.');
                    return $this->redirect(['action' => 'index']);
                } else {
                    $this->Flash->error('The user could not be saved. Please, try again.');
                }
            }
        }

        $this->set(compact('user', 'userlog', 'parentUsers', 'user_fields', 'user_types'));
        $this->set('_serialize', ['user', 'userlog', 'user_fields', 'user_types']);
    }

    public function random($length = 15) {
        $chars = 'bc$d%^f&ghjklm#nprst@vw(xz)ae-iou';
        $result = '';
        for ($p = 0; $p < $length; $p++) {
            $result .= ($p % 2) ? $chars[mt_rand(19, 23)] : $chars[mt_rand(0, 18)];
        }

        return $result;
    }

    /**
     * Add method
     *
     * @return void Redirects on successful add, renders view otherwise.
     */
    public function add() {
        $user = $this->Users->newEntity();
        $user_fields = $this->UserFields->find('all');
        $user_types = $this->UserTypes->find('list', [
                    'keyField' => 'field_name',
                    'valueField' => 'field_title',
                ])->toArray();
        foreach ($user_types as $key => $value):
            $user->accessible($key, true);
        endforeach;
        foreach ($user_fields as $user_field):
            $user->accessible($user_field->field_name, true);
        endforeach;
        if ($this->request->is('post')) {
            $user = $this->Users->patchEntity($user, $this->request->data);
            $result = $this->Users->save($user);
            $user_id = $result->id;
            $user = $this->Users->get($user_id, [
                'contain' => []
            ]);
            $message = ($result) ? __('User Created Successfully !') : __('There is Some proble while createing User Account ! Please Try After Some Time');

            if ($result) {

                if (!isset($this->request->data['image']['error']) ? $this->request->data['image']['error'] : TRUE) {
                    $file = $this->Users->saveFile($user_id, $this->request->data['image'], $user);
                }
                $this->Flash->success($message);
                return $this->redirect(['action' => 'index']);
            } else {
                $this->Flash->error($message);
            }
        }
        $this->set(compact('user', 'parentUsers', 'user_fields', 'user_types'));

        $this->set('_serialize', ['user', 'user_fields', 'user_types']);
        $this->set('isEdit', FALSE);
    }

    /**
     * Edit method
     *
     * @param string|null $id User id.
     * @return void Redirects on successful edit, renders view otherwise.
     * @throws \Cake\Network\Exception\NotFoundException When record not found.
     */
    public function edit($id = null) {
        if (is_null($id))
            $id = $this->current_user['id'];

        $user = $this->Users->get($id, [
            'contain' => []
        ]);
        $user_id = $id;
        $user_fields = $this->UserFields->find('all');
        $user_types = $this->UserTypes->find('list', [
                    'keyField' => 'field_name',
                    'valueField' => 'field_title',
                ])->toArray();
        foreach ($user_types as $key => $value):
            $user->accessible($key, true);
        endforeach;
        foreach ($user_fields as $user_field):
            $user->accessible($user_field->field_name, true);
        endforeach;
        if ($this->request->is(['patch', 'post', 'put'])) {
            $imageData = array();
            $imageData = $this->request->data['image'];
            unset($this->request->data['image']);
            $user = $this->Users->patchEntity($user, $this->request->data);
            if ($result = $this->Users->save($user)) {
                $user_id = $result->id;
                if (!isset($imageData['error']) ? $imageData['error'] : TRUE) {
                    $file = $this->Users->saveFile($user_id, $imageData, $user);
                }
                $this->Flash->success('The user has been saved.');
                return $this->redirect(['action' => 'index']);
            } else {
                $this->Flash->error('The user could not be saved. Please, try again.');
            }
        }
        $this->set(compact('user', 'parentUsers', 'user_fields', 'user_types'));
        $this->set('_serialize', ['user', 'user_fields', 'user_types']);
        $this->set('isEdit', TRUE);

        $this->userData = $user;
    }

    /**
     * Edit method
     *
     * @param string|null $id User id.
     * @return void Redirects on successful edit, renders view otherwise.
     * @throws \Cake\Network\Exception\NotFoundException When record not found.
     */
    public function adminedit($id = null) {
        if (is_null($id))
            $id = $this->current_user['id'];

        $user = $this->Users->get($id, [
            'contain' => []
        ]);

        if ($this->request->is(['patch', 'post', 'put'])) {
            $user = $this->Users->patchEntity($user, $this->request->data);
            if ($result = $this->Users->save($user)) {
                $this->Flash->success('The user has been saved.');
                return $this->redirect(['action' => 'adminedit', 1]);
            } else {
                $this->Flash->error('The user could not be saved. Please, try again.');
            }
        }
        $this->set(compact('user', 'user_fields', 'user_types'));
        $this->set('_serialize', ['user', 'user_fields', 'user_types']);
        $this->set('isEdit', TRUE);

        $this->userData = $user;
    }

    /**
     * Delete method
     *
     * @param string|null $id User id.
     * @return void Redirects to index.
     * @throws \Cake\Network\Exception\NotFoundException When record not found.
     */
    public function delete($id = null) {
        $this->request->allowMethod(['post', 'delete']);
        $user = $this->Users->get($id);
        if ($this->Users->delete($user)) {
            $this->Flash->success('The user has been deleted.');
        } else {
            $this->Flash->error('The user could not be deleted. Please, try again.');
        }
        return $this->redirect(['action' => 'index']);
    }

    /**
     * 
     * Upon Success redirect the User to Dashboard or Render the Login Page
     * 
     * @return void
     */
    public function login() {
        /**
         * 
         * Redirect the logged in user from this action
         */
        if ($this->Auth->user()) {
            $this->redirect('/');
            return;
        }

        if ($this->request->is('post')) {
            $user = $this->Auth->identify();
            $authenitcated = FALSE;
            if (!empty($user)) {
                $user_type = $this->request->data['user_type'];
                if ($user[$user_type] == 1) {
                    $authenitcated = TRUE;
                }
            }
            if ($authenitcated) {
                $this->Auth->setUser($user);
                return $this->redirect($this->Auth->redirectUrl());
            }
            $this->Flash->error(__('You are not authorized user'));
        }
        $this->viewBuilder()->layout('login');
    }

    public function rnd() {

        $this->Users->rnd();
        die('we are here');
        $email = new Email('default');
        $email->template('default')
                ->emailFormat('both')
                ->to('anand@phpconsultant.co')
                ->subject('Testing E-mail From Mandril Cakephp 3 ')
                ->viewVars(['content' => 'This is Testing E-mail From Mandril Cakephp 3 skhkshdhksh '])
                ->send();
        die('we are here');
    }

    /**
     * 
     * Redirect User back to login page and Log them out
     * 
     * @return void
     */
    public function logout() {
        $session = $this->request->session();
        $session->delete('userType');
        $session->delete('userControllers');
        $session->delete('controllersAction');
        return $this->redirect($this->Auth->logout());
    }

    public function beforeRender(Event $event) {

        $this->breadcrumbs[] = array(
            'label' => __('User'),
            'link' => array(
                'controller' => 'Users',
                'action' => 'index',
            ),
        );

        switch ($this->request->params['action']) {
            default:
                $this->showBreadcrumb = FALSE;
                break;
            case 'index':
                break;
            case 'add':
                $this->breadcrumbs[] = array(
                    'label' => __('Add'),
                );
                break;
            case 'edit':

                $this->breadcrumbs[] = array(
                    'label' => __('Edit'),
                );

                $this->breadcrumbs[] = array(
                    'label' => $this->userData->first_name . ' ' . $this->userData->last_name,
                );

                break;
        }

        parent::beforeRender($event);
    }

    /**
     * Fields Index method
     *
     * @return void
     */
    public function user_fields() {
        $this->paginate = [];
        $this->set('user_fields', $this->paginate($this->UserFields));
        $this->set('_serialize', ['user_fields']);
    }

    /**
     * Add Field method
     *
     * @return void Redirects on successful add, renders view otherwise.
     */
    public function add_field() {
        $user_field = $this->UserFields->newEntity();
        if ($this->request->is('post')) {
            $userNewColumn = '';
            $fieldName = $this->UserFields->getFieldName($this->request->data['field_title']);
            $userColumn = $this->conn->query("SELECT `COLUMN_NAME` FROM `INFORMATION_SCHEMA`.`COLUMNS` WHERE `TABLE_SCHEMA`='" . DB . "' AND `TABLE_NAME`='users'");
            $fields = array();
            foreach ($userColumn as $column) {
                $fields[] = $column['COLUMN_NAME'];
            }
            if (in_array($fieldName, $fields)) {
                $message = __('Field name already taken please try another');
            } else {
                $userNewColumn = $this->conn->query("ALTER TABLE users ADD " . $fieldName . " varchar(" . $this->request->data['field_limit'] . ") NULL");
            }

            if ($userNewColumn) {
                $this->request->data['field_name'] = $fieldName;
                $user_field = $this->UserFields->patchEntity($user_field, $this->request->data);
                $result = $this->UserFields->save($user_field);
                $user_id = $result->id;
                $message = ($result) ? __('User Field Created Successfully !') : __('There is Some proble while createing User Field ! Please Try After Some Time');
                $this->Flash->success($message);
                return $this->redirect(['action' => 'user_fields']);
            } else {
                $this->Flash->error($message);
            }
        }
        $this->set(compact('user_field'));

        $this->set('_serialize', ['user_field']);
        $this->set('isEdit', FALSE);
    }

    /**
     * Delete Field method
     *
     * @return void Redirects on successful add, renders view otherwise.
     */
    public function field_delete($id = null) {
        $this->request->allowMethod(['post', 'delete']);
        $userField = $this->UserFields->get($id);
        if ($this->UserFields->delete($userField)) {
            $userColumn = $this->conn->query("ALTER TABLE users DROP COLUMN " . $userField->field_name);
            $userColumn = $this->conn->query("ALTER TABLE userlogs DROP COLUMN " . $userField->field_name);
            $this->Flash->success('The user field has been deleted.');
        } else {
            $this->Flash->error('The user field could not be deleted. Please, try again.');
        }
        return $this->redirect(['action' => 'user_fields']);
    }

    /**
     * User Type Index method
     *
     * @return void
     */
    public function user_types() {
        $this->paginate = [];
        $this->set('user_types', $this->paginate($this->UserTypes));
        $this->set('_serialize', ['user_types']);
    }

    /**
     * Add User Types method
     *
     * @return void Redirects on successful add, renders view otherwise.
     */
    public function add_usertype() {
        $user_type = $this->UserTypes->newEntity();
        if ($this->request->is('post')) {
            $userNewColumn = '';
            $fieldName = $this->UserTypes->getFieldName($this->request->data['field_title']);
            $userColumn = $this->conn->query("SELECT `COLUMN_NAME` FROM `INFORMATION_SCHEMA`.`COLUMNS` WHERE `TABLE_SCHEMA`='" . DB . "' AND `TABLE_NAME`='users'");
            $fields = array();
            foreach ($userColumn as $column) {
                $fields[] = $column['COLUMN_NAME'];
            }
            if (in_array($fieldName, $fields)) {
                $message = __('Field name already taken please try another');
            } else {
                $userNewColumn = $this->conn->query("ALTER TABLE users ADD " . $fieldName . " int(" . $this->request->data['field_limit'] . ") DEFAULT 0");
            }

            if ($userNewColumn) {
                $this->request->data['user_controllers'] = implode(',', $this->request->data['all_controllers']);
                $controllersCount = count($this->request->data['all_controllers']);
                $actionsArr = array();
                for ($i = 0; $i < $controllersCount; $i++) {
                    $mainIndex = $this->request->data['all_controllers'][$i];
                    $add = $this->request->data['add_' . $mainIndex];
                    $edit = $this->request->data['edit_' . $mainIndex];
                    $delete = $this->request->data['delete_' . $mainIndex];
                    $others = $this->request->data['others_' . $mainIndex];
                    $actionsArr[$mainIndex]['add'] = $add;
                    $actionsArr[$mainIndex]['edit'] = $edit;
                    $actionsArr[$mainIndex]['delete'] = $delete;
                    $actionsArr[$mainIndex]['others'] = $others;
                }
                $actionSerialize = serialize($actionsArr);
                $this->request->data['controllers_action'] = $actionSerialize;
                $this->request->data['field_name'] = $fieldName;
                $user_type = $this->UserTypes->patchEntity($user_type, $this->request->data);
                $result = $this->UserTypes->save($user_type);
                $user_id = $result->id;
                $message = ($result) ? __('User Type Created Successfully !') : __('There is Some proble while createing User Type ! Please Try After Some Time');
                $this->Flash->success($message);
                return $this->redirect(['action' => 'user_types']);
            } else {
                $this->Flash->error($message);
            }
        }
        $this->set(compact('user_type'));

        $this->set('_serialize', ['user_type']);
        $this->set('isEdit', FALSE);
    }

    /**
     * Delete User Type method
     *
     * @return void Redirects on successful add, renders view otherwise.
     */
    public function usertype_delete($id = null) {
        $this->request->allowMethod(['post', 'delete']);
        $userType = $this->UserTypes->get($id);
        if ($this->UserTypes->delete($userType)) {
            $userColumn = $this->conn->query("ALTER TABLE users DROP COLUMN " . $userType->field_name);
            $userColumn = $this->conn->query("ALTER TABLE userlogs DROP COLUMN " . $userType->field_name);
            $this->Flash->success('The user field has been deleted.');
        } else {
            $this->Flash->error('The user field could not be deleted. Please, try again.');
        }
        return $this->redirect(['action' => 'user_types']);
    }

    /**
     * Edit User Types method
     *
     * @return void Redirects on successful add, renders view otherwise.
     */
    public function edit_usertype($id = null) {
        $user_type = $this->UserTypes->get($id, [
            'contain' => []
        ]);
        if ($this->request->is('post')) {
            $this->request->data['user_controllers'] = implode(',', $this->request->data['all_controllers']);
            $controllersCount = count($this->request->data['all_controllers']);
            $actionsArr = array();
            for ($i = 0; $i < $controllersCount; $i++) {
                $mainIndex = $this->request->data['all_controllers'][$i];
                $add = $this->request->data['add_' . $mainIndex];
                $edit = $this->request->data['edit_' . $mainIndex];
                $delete = $this->request->data['delete_' . $mainIndex];
                $others = $this->request->data['others_' . $mainIndex];
                $actionsArr[$mainIndex]['add'] = $add;
                $actionsArr[$mainIndex]['edit'] = $edit;
                $actionsArr[$mainIndex]['delete'] = $delete;
                $actionsArr[$mainIndex]['others'] = $others;
            }
            $actionSerialize = serialize($actionsArr);
            $this->request->data['controllers_action'] = $actionSerialize;
            $user_type = $this->UserTypes->patchEntity($user_type, $this->request->data);
            $result = $this->UserTypes->save($user_type);
            $user_id = $result->id;
            $message = ($result) ? __('User Type Created Successfully !') : __('There is Some proble while createing User Type ! Please Try After Some Time');
            $this->Flash->success($message);
            return $this->redirect(['action' => 'user_types']);
        }
        $this->set(compact('user_type'));

        $this->set('_serialize', ['user_type']);
        $this->set('isEdit', TRUE);
    }

    public function getUsers() {
        $company_id = $this->request->query['company_id'];
        $department_id = $this->request->query['department_id'];
        $designation_id = $this->request->query['designation_id'];
        $users = $this->Users->find('list', [
                    'keyField' => 'id',
                    'valueField' => 'name',
                    'conditions' => [
                        'Users.company_id' => $company_id,
                        'Users.department_id' => $department_id,
                        'Users.designation_id' => $designation_id
                    ],
                ])->where(['status' => 'active'])->toArray();

        if (empty($users)) {
            $response = [
                'states' => 'error',
                'message' => __('Seems to be Wrong Country Id'),
                'data' => array(),
            ];
        } else {
            $response = [
                'status' => 'success',
                'data' => $users,
            ];
        }

        $this->set('response', $response);

        $this->layout = 'ajax';
        $this->render('/Element/Ajax/get');
    }

    public function getHODUsers() {
        $company_id = $this->request->query['company_id'];
        $department_id = $this->request->query['department_id'];
        $designation_id = 2;
        $users = $this->Users->find('list', [
                    'keyField' => 'id',
                    'valueField' => 'name',
                    'conditions' => [
                        'Users.company_id' => $company_id,
                        'Users.department_id' => $department_id,
                        'Users.designation_id' => $designation_id
                    ],
                ])->where(['status' => 'active'])->toArray();

        if (empty($users)) {
            $response = [
                'states' => 'error',
                'message' => __('Seems to be Wrong Country Id'),
                'data' => array(),
            ];
        } else {
            $response = [
                'status' => 'success',
                'data' => $users,
            ];
        }

        $this->set('response', $response);

        $this->layout = 'ajax';
        $this->render('/Element/Ajax/get');
    }

    public function getReportManagerUsers() {
        $company_id = $this->request->query['company_id'];
        $department_id = $this->request->query['department_id'];
        $designation_id = 4;
        $users = $this->Users->find('list', [
                    'keyField' => 'id',
                    'valueField' => 'name',
                    'conditions' => [
                        'Users.company_id' => $company_id,
                        'Users.department_id' => $department_id,
                        'Users.designation_id' => $designation_id
                    ],
                ])->where(['status' => 'active'])->toArray();

        if (empty($users)) {
            $response = [
                'states' => 'error',
                'message' => __('Seems to be Wrong Country Id'),
                'data' => array(),
            ];
        } else {
            $response = [
                'status' => 'success',
                'data' => $users,
            ];
        }

        $this->set('response', $response);

        $this->layout = 'ajax';
        $this->render('/Element/Ajax/get');
    }

}
